<?php
function _uploadArchive(&$tof,$vars) {
	require_once("actions/roll.php");
	require_once("actions/topic.php");
	require_once("actions/uploads.php");
	$tof->log(sprintf(_('Uploading archive %s'),$_FILES['file']['name']));
	$rollID = maybeCreateRoll($tof,$vars['NewRollID'],$vars['RollID']);
	$topicID = maybeCreateTopic(
		$tof,
		$vars['ParentTopicID'],
		$vars['NewTopicDescription'],
		array(EVERYBODY),
		array(READ,WRITE));
	uploadArchive(
		$tof,
		$_FILES['file']['tmp_name'],
		$_FILES['file']['name'],
		$_FILES['file']['size'],
		$_FILES['file']['type'],
		$rollID,
		$topicID,
		$vars['Groups']);
}
?>